@@ -36,20 +36,20 @@ class RabbitmqClient(object):
             try:
                 credentials = pika.credentials.PlainCredentials(username=self._user, password=self._passwd)
                 self._rabbit_conn = pika.BlockingConnection(pika.ConnectionParameters(host=self._host,
-                                                            port=self._port,
-                                                            credentials=credentials,
-                                                            virtual_host=self._vhost))
+                                                                                      port=self._port,
+                                                                                      credentials=credentials,
+                                                                                      virtual_host=self._vhost))
                 self._channel = self._rabbit_conn.channel()
-                self._channel.exchange_declare(exchange=self._exchange_name, 
-                                            exchange_type=self._exchange_type, 
-                                            durable=self._durable)
+                self._channel.exchange_declare(exchange=self._exchange_name,
+                                               exchange_type=self._exchange_type,
+                                               durable=self._durable)
                 if self._queue:
                     q = self._channel.queue_declare(queue=self._queue,
                                                     durable=self._durable,
                                                     exclusive=False)
                     self._channel.queue_bind(queue=self._queue,
-                                                exchange=self._exchange_name,
-                                                routing_key=self._routing_key)
+                                             exchange=self._exchange_name,
+                                             routing_key=self._routing_key)
                     self._channel.basic_qos(prefetch_count=1)
                 self._connected = True
                 log_info('Succeed to connect {}:{} rabbit mq'.format(self._host, self._port))
@@ -58,7 +58,7 @@ class RabbitmqClient(object):
                                                                                  self._port, str(e)))
         return self._connected
 
-    def publish_msg(self, msg_str, retry=5):
+    def publish_msg(self, msg_str, retry=5, expiration=0):
         need_loop = False
         if retry <= 0:
             need_loop = True
@@ -68,9 +68,17 @@ class RabbitmqClient(object):
                                                                                 self._port, self._user))
                 time.sleep(0.5)
             try:
-                self._channel.basic_publish(exchange=self._exchange_name,
-                                            routing_key=self._routing_key,
-                                            body=msg_str)
+                if expiration > 0:
+                    self._channel.basic_publish(exchange=self._exchange_name,
+                                                routing_key=self._routing_key,
+                                                properties=pika.BasicProperties(
+                                                    expiration=str(expiration),
+                                                ),
+                                                body=msg_str)
+                else:
+                    self._channel.basic_publish(exchange=self._exchange_name,
+                                                routing_key=self._routing_key,
+                                                body=msg_str)
                 return True
             except Exception as e:
                 log_error('publish msg error({})'.format(e))
@@ -123,7 +131,7 @@ class RabbitmqClient(object):
                 sleep(0.1)
 
     def queue_message_count(self, queue_name, retry=5):
-        while retry>0:
+        while retry > 0:
             while not self._connect():
                 sleep(0.1)
             try:
@@ -138,7 +146,7 @@ class RabbitmqClient(object):
         return False
 
     def queue_bind_consumer_count(self, queue_name, retry=5):
-        while retry>0:
+        while retry > 0:
             while not self._connect():
                 sleep(0.1)
             try:
