@@ -1,3 +1,5 @@
+import sys
+sys.path.append('.')
 from libra_core.log import *
 
 
@@ -30,3 +32,6 @@ def test_log_exception():
         print(1 / 0)
     except Exception as ex:
         log_exception(ex, "print failed")
+
+if __name__ == "__main__":
+    test_log_info()
